# flake8: noqa
"""
Configuration file of the project
"""
# Config variables taken from
# https://github.com/ping/instagram_private_api/blob/master/
#   instagram_private_api/constants.py
API_DOMAIN = "i.instagram.com"
API_URL = "https://{domain}/api/v1/".format(domain=API_DOMAIN)
USER_AGENT_BASE = (
    "Instagram {instagram_version} "
    "Android ({android_version}/{android_release}; "
    "{dpi}; {resolution}; {manufacturer}; "
    "{device}; {model}; {cpu}; en_US)"
)
SIG_KEY_VERSION = "4"
# version 105.0.0.18.119 (166149665)
# August 6, 2019 from https://www.apkmirror.com/apk/instagram/
#   instagram-instagram/instagram-instagram-105-0-0-18-119-
#   release/instagram-105-0-0-18-119-4-android-apk-download/
# Check website regularly to update IG_SIG_KEY and
# X-IG-Capabilities in REQUEST_HEADERS
IG_SIG_KEY = "5f3e50f435583c9ae626302a71f7340044087a7e2c60adacfc254205a993e305"

# Request variables taken from
# https://github.com/ping/instagram_private_api/blob/
#   422d61f0a8cc9de3d5a0e78bcba53751c44e5d63/
#   instagram_private_api/client.py#L375
REQUEST_HEADERS = {
    "Connection": "Keep-Alive",
    # version 105.0.0.18.119 (166149665)
    # python3 -c "import base64, struct; print(base64.b64encode(
    #   struct.pack('<i', 166149665)).decode('ascii'));"
    "X-IG-Capabilities": "IT7nCQ==",
    "X-IG-App-ID": "567067343352427",
    "X-IG-Connection-Type": "WIFI",
    "X-IG-Prefetch-Request": "foreground",
    "X-IG-VP9-Capable": "false",
    "X-FB-HTTP-Engine": "Liger",
    "Accept": "*/*",
    "Accept-Encoding": "gzip,deflate",
    "Accept-Language": "en-US",
    "Content-type": "application/x-www-form-urlencoded; charset=UTF-8",
    "Cookie2": "$Version=1",
}

# Moved to the end as it's quite long
EXPERIMENTS = (
    "ig_android_sticker_search_explorations,android_ig_camera_ar_asset_manager"
    "_improvements_universe,ig_android_stories_seen_state_serialization,ig_sto"
    "ries_photo_time_duration_universe,ig_android_bitmap_cache_executor_size,i"
    "g_android_stories_music_search_typeahead,ig_android_delayed_comments,ig_a"
    "ndroid_switch_back_option,ig_android_video_profiler_loom_traces,ig_androi"
    "d_paid_branded_content_rendering,ig_android_direct_app_reel_grid_search,i"
    "g_android_stories_no_inflation_on_app_start,ig_android_camera_sdk_check_g"
    "l_surface_r2,ig_promote_review_screen_title_universe,ig_android_direct_ne"
    "wer_single_line_composer_universe,ig_direct_holdout_h1_2019,ig_explore_20"
    "19_h1_destination_cover,ig_android_direct_stories_in_direct_inbox,ig_fb_g"
    "raph_differentiation_no_fb_data,ig_android_recyclerview_binder_group_enab"
    "led_universe,ig_android_direct_share_sheet_custom_fast_scroller,ig_androi"
    "d_video_exoplayer_2,ig_android_shopping_channel_in_explore,ig_android_sto"
    "ries_music_filters,ig_android_2018_h1_hashtag_report_universe,ig_android_"
    "live_replay_highlights_universe,ig_android_hashtag_page_reduced_related_i"
    "tems,ig_android_live_titles_broadcaster_side_create_title_universe,ig_and"
    "roid_fbns_preload_direct_universe,ig_android_prefetch_carousels_on_swipe_"
    "universe,ig_camera_network_activity_logger,ig_camera_remove_display_rotat"
    "ion_cb_universe,ig_android_interactions_migrate_inline_composer_to_viewpo"
    "int_universe,ig_android_realtime_always_start_connection_on_condition_uni"
    "verse,ig_android_ad_leadgen_single_screen_universe,ig_android_enable_zero"
    "_rating,ig_android_import_page_post_after_biz_conversion,ig_camera_ar_eff"
    "ect_attribution_position,ig_android_vc_call_ended_cleanup_universe,ig_sto"
    "ries_engagement_holdout_2019_h1_universe,ig_android_story_import_intent,i"
    "g_direct_report_conversation_universe,ig_biz_graph_connection_universe,ig"
    "_android_codec_high_profile,ig_android_nametag,ig_android_sso_family_key_"
    "universe,ig_android_parse_direct_messages_bytes_universe,ig_hashtag_creat"
    "ion_universe,ig_android_gallery_order_by_date_taken,ig_android_igtv_resha"
    "re,ig_end_of_feed_universe,ig_android_share_others_post_reorder,ig_androi"
    "d_additional_contact_in_nux,ig_android_live_use_all_preview_sizes,ig_andr"
    "oid_clarify_invite_options,ig_android_live_align_by_2_universe,ig_android"
    "_separate_network_executor,ig_android_realtime_manager_optimization,ig_an"
    "droid_auto_advance_su_unit_when_scrolled_off_screen,ig_android_network_ca"
    "ncellation,ig_android_media_as_sticker,ig_android_stories_video_prefetch_"
    "kb,ig_android_maintabfragment,ig_inventory_connections,ig_stories_injecti"
    "on_tool_enabled_universe,ig_android_stories_disable_highlights_media_prel"
    "oading,ig_android_live_start_broadcast_optimized_universe,ig_android_stor"
    "ies_question_response_mutation_universe,ig_android_onetap_upsell_change_p"
    "wd,ig_nametag_data_collection,ig_android_disable_scroll_listeners,ig_andr"
    "oid_persistent_nux,ig_android_igtv_audio_always_on,ig_android_enable_lige"
    "r_preconnect_universe,ig_android_persistent_duplicate_notif_checker_user_"
    "based,ig_android_rate_limit_mediafeedviewablehelper,ig_android_search_rem"
    "ove_null_state_sections,ig_android_stories_viewer_drawable_cache_universe"
    ",ig_direct_android_reply_modal_universe,ig_android_biz_qp_suggest_page,ig"
    "_shopping_indicator_content_variations_android,ig_android_stories_reel_me"
    "dia_item_automatic_retry,ig_fb_notification_universe,ig_android_live_disa"
    "ble_speed_test_ui_timeout_universe,ig_android_direct_thread_scroll_perf_o"
    "ncreate_universe,ig_android_low_data_mode_backup_2,ig_android_invite_xout"
    "_universe,ig_android_low_data_mode_backup_3,ig_android_low_data_mode_back"
    "up_4,ig_android_low_data_mode_backup_5,ig_android_video_abr_universe,ig_a"
    "ndroid_low_data_mode_backup_1,ig_android_signup_refactor_santity,ig_chall"
    "enge_general_v2,ig_android_place_signature_universe,ig_android_hide_butto"
    "n_for_invite_facebook_friends,ig_android_business_promote_tooltip,ig_andr"
    "oid_follow_requests_ui_improvements,ig_android_shopping_post_tagging_nux_"
    "universe,ig_android_stories_sensitivity_screen,ig_android_camera_arengine"
    "_shader_caching_universe,ig_android_insta_video_broadcaster_infra_perf,ig"
    "_android_direct_view_more_qe,ig_android_direct_visual_message_prefetch_co"
    "unt_universe,ig_camera_android_ar_effect_stories_deeplink,ig_android_clie"
    "nt_side_delivery_universe,ig_android_stories_send_client_reels_on_tray_fe"
    "tch_universe,ig_android_direct_inbox_background_view_models,ig_android_st"
    "artup_thread_priority,ig_android_stories_viewer_responsiveness_universe,i"
    "g_android_live_use_rtc_upload_universe,ig_android_live_ama_viewer_univers"
    "e,ig_android_business_id_conversion_universe,ig_smb_ads_holdout_2018_h2_u"
    "niverse,ig_android_modal_activity_no_animation_fix_universe,ig_android_ca"
    "mera_post_smile_low_end_universe,ig_android_live_realtime_comments_univer"
    "se,ig_android_vc_in_app_notification_universe,ig_eof_caboose_universe,ig_"
    "android_new_one_tap_nux_universe,ig_android_igds_edit_profile_fields,ig_a"
    "ndroid_downgrade_viewport_exit_behavior,ig_android_mi_batch_upload_univer"
    "se,ig_camera_android_segmentation_async_universe,ig_android_use_recyclerv"
    "iew_for_direct_search_universe,ig_android_live_comment_fetch_frequency_un"
    "iverse,ig_android_create_page_on_top_universe,ig_android_direct_log_badge"
    "_count_inconsistent,ig_android_stories_text_format_emphasis,ig_android_qu"
    "estion_sticker_replied_state,ig_android_ad_connection_manager_universe,ig"
    "_android_image_upload_skip_queue_only_on_wifi,ig_android_ad_watchbrowse_c"
    "arousel_universe,ig_android_interactions_show_verified_badge_for_preview_"
    "comments_universe,ig_stories_question_sticker_music_format_prompt,ig_andr"
    "oid_activity_feed_row_click,ig_android_hide_crashing_newsfeed_story_t3813"
    "1972,ig_android_video_upload_quality_qe1,ig_android_save_collaborative_co"
    "llections,ig_android_location_attribution_text,ig_camera_android_profile_"
    "ar_notification_universe,coupon_price_test_boost_instagram_media_acquisit"
    "ion_universe,ig_android_video_outputsurface_handlerthread_universe,ig_and"
    "roid_country_code_fix_universe,ig_perf_android_holdout_2018_h1,ig_android"
    "_stories_music_overlay,ig_android_enable_lean_crash_reporting_universe,ig"
    "_android_resumable_downloads_logging_universe,ig_android_stories_default_"
    "rear_camera_universe,ig_android_low_latency_consumption_universe,ig_andro"
    "id_offline_mode_holdout,ig_android_foreground_location_collection,ig_andr"
    "oid_stories_close_friends_disable_first_time_badge,ig_android_react_nativ"
    "e_universe_kill_switch,ig_android_video_ta_universe,ig_android_media_rows"
    "_async_inflate,ig_android_stories_gallery_video_segmentation,ig_android_s"
    "tories_in_feed_preview_notify_fix_universe,ig_android_video_rebind_force_"
    "keep_playing_fix,ig_android_direct_business_holdout,ig_android_xposting_u"
    "psell_directly_after_sharing_to_story,ig_android_gallery_high_quality_pho"
    "to_thumbnails,ig_android_interactions_new_comment_like_pos_universe,ig_fe"
    "ed_core_experience_universe,ig_android_friends_sticker,ig_android_busines"
    "s_ix_universe,ig_android_suggested_highlights,ig_android_stories_posting_"
    "offline_ui,ig_android_stories_close_friends_rings_remove_green_universe,i"
    "g_android_canvas_tilt_to_pan_universe,ig_android_vc_background_call_toast"
    "_universe,ig_android_concurrent_cold_start_universe,ig_promote_default_de"
    "stination_universe,mi_viewpoint_viewability_universe,ig_android_location_"
    "page_info_page_upsell,igds_android_listrow_migration_universe,ig_direct_r"
    "eshare_sharesheet_ranking,ig_android_fb_sync_options_universe,ig_android_"
    "drawable_usage_logging_universe,ig_android_recommend_accounts_destination"
    "_routing_fix,ig_android_fix_prepare_direct_push,ig_direct_android_larger_"
    "media_reshare_style,ig_android_video_feed_universe,ig_android_building_ay"
    "mf_universe,ig_android_internal_sticker_universe,ig_traffic_routing_unive"
    "rse,ig_android_search_normalization,ig_android_ad_watchmore_entry_point_u"
    "niverse,ig_camera_android_segmentation_enabled_universe,ig_android_igtv_a"
    "lways_show_browse_ui,ig_android_page_claim_deeplink_qe,ig_explore_2018_h2"
    "_account_rec_deduplication_android,ig_android_story_accidentally_click_in"
    "vestigation_universe,ig_android_shopping_pdp_hero_carousel,ig_android_cle"
    "ar_inflight_image_request,ig_android_show_su_in_other_users_follow_list,i"
    "g_android_stories_infeed_lower_threshold_launch,ig_android_main_feed_vide"
    "o_countdown_timer,instagram_interests_holdout,ig_android_continuous_video"
    "_capture,ig_android_category_search_edit_profile,ig_android_contact_invit"
    "es_nux_universe,ig_android_settings_search_v2_universe,ig_android_video_u"
    "pload_iframe_interval,ig_business_new_value_prop_universe,ig_android_powe"
    "r_metrics,ig_android_stories_collapse_seen_segments,ig_android_live_follo"
    "w_from_comments_universe,ig_android_hashtag_discover_tab,ig_android_live_"
    "skip_live_encoder_pts_correction,ig_android_reel_zoom_universe,enable_cre"
    "ator_account_conversion_v0_universe,ig_android_test_not_signing_address_b"
    "ook_unlink_endpoint,ig_android_direct_tabbed_media_picker,ig_android_dire"
    "ct_mutation_manager_job_scheduler,ig_ei_option_setting_universe,ig_androi"
    "d_hashtag_related_items_over_logging,ig_android_livewith_liveswap_optimiz"
    "ation_universe,ig_android_direct_new_intro_card,ig_camera_android_support"
    "ed_capabilities_api_universe,ig_android_video_webrtc_textureview,ig_andro"
    "id_share_claim_page_universe,ig_direct_android_mentions_sender,ig_android"
    "_whats_app_contact_invite_universe,ig_android_video_scrubber_thumbnail_un"
    "iverse,ig_camera_ar_image_transform_library,ig_android_insights_creation_"
    "growth_universe,ig_android_igtv_refresh_tv_guide_interval,ig_android_stor"
    "ies_gif_sticker,ig_android_stories_music_broadcast_receiver,ig_android_fb"
    "_profile_integration_fbnc_universe,ig_android_low_data_mode,ig_fb_graph_d"
    "ifferentiation_control,ig_android_show_create_content_pages_universe,ig_a"
    "ndroid_igsystrace_universe,ig_android_new_contact_invites_entry_points_un"
    "iverse,ig_android_ccu_jobscheduler_inner,ig_android_netego_scroll_perf,ig"
    "_android_fb_connect_follow_invite_flow,ig_android_invite_list_button_rede"
    "sign_universe,ig_android_react_native_email_sms_settings_universe,ig_andr"
    "oid_igtv_aspect_ratio_limits,ig_hero_player,ig_android_save_auto_sharing_"
    "to_fb_option_on_server,ig_android_live_presence_universe,ig_android_white"
    "hat_options_universe,android_cameracore_preview_frame_listener2_ig_univer"
    "se,ig_android_memory_manager,ig_account_recs_in_chaining,ig_explore_2018_"
    "finite_chain_android_universe,ig_android_tagging_video_preview,ig_android"
    "_feed_survey_viewpoint,ig_android_hashtag_search_suggestions,ig_android_p"
    "rofile_neue_infra_rollout_universe,ig_android_instacrash_detection,ig_and"
    "roid_interactions_add_search_bar_to_likes_list_universe,ig_android_vc_cap"
    "ture_universe,ig_nametag_local_ocr_universe,ig_branded_content_share_to_f"
    "acebook,ig_android_direct_segmented_video,ig_android_search_page_v2,ig_an"
    "droid_stories_recently_captured_universe,ig_business_integrity_ipc_univer"
    "se,ig_android_share_product_universe,ig_fb_graph_differentiation_top_k_fb"
    "_coefficients,ig_shopping_viewer_share_action,ig_android_direct_share_sto"
    "ry_to_facebook,ig_android_business_attribute_sync,ig_android_video_time_t"
    "o_live_cache_eviction,ig_android_location_feed_related_business,ig_androi"
    "d_view_and_likes_cta_universe,ig_live_holdout_h2_2018,ig_android_profile_"
    "memories_universe,ig_promote_budget_warning_view_universe,ig_android_redi"
    "rect_to_web_on_oembed_fail_universe,ig_android_optic_new_focus_controller"
    ",ig_android_shortcuts,ig_android_search_hashtag_badges,ig_android_navigat"
    "ion_latency_logger,ig_android_direct_composer_avoid_hiding_thread_camera,"
    "ig_android_direct_remix_visual_messages,ig_android_custom_story_import_in"
    "tent,ig_android_biz_new_choose_category,ig_android_view_info_universe,ig_"
    "android_camera_upsell_dialog,ig_android_business_ix_self_serve,ig_android"
    "_dead_code_detection,ig_android_ad_watchbrowse_universe,ig_android_pbia_p"
    "roxy_profile_universe,ig_android_qp_kill_switch,ig_android_gap_rule_enfor"
    "cer_universe,ig_android_direct_delete_or_block_from_message_requests,ig_a"
    "ndroid_direct_left_aligned_navigation_bar,ig_android_feed_load_more_viewp"
    "oint_universe,ig_android_stories_reshare_reply_msg,ig_android_one_tap_sha"
    "resheet_fb_extensions,ig_android_stories_feeback_message_composer_entry_p"
    "oint,ig_direct_holdout_h2_2018,ig_camera_android_facetracker_v12_universe"
    ",ig_android_camera_ar_effects_low_storage_universe,ig_camera_android_blac"
    "k_feed_sticker_fix_universe,ig_android_direct_media_forwarding,ig_android"
    "_camera_attribution_in_direct,ig_android_audience_control,ig_android_stor"
    "ies_cross_sharing_to_fb_holdout_universe,ig_android_enable_main_feed_reel"
    "_tray_preloading,ig_android_profile_neue_universe,ig_company_profile_hold"
    "out,ig_camera_android_areffect_photo_capture_universe,ig_rti_inapp_notifi"
    "cations_universe,ig_android_vc_join_timeout_universe,ig_android_feed_core"
    "_ads_2019_h1_holdout_universe,ig_android_interactions_composer_mention_se"
    "arch_universe,ig_android_igtv_save,ig_android_follower_following_whatsapp"
    "_invite_universe,ig_android_claim_location_page,ig_android_story_ads_2019"
    "_h1_holdout_universe,ig_android_3pspp,ig_android_cache_timespan_objects,i"
    "g_timestamp_public_test,ig_android_histogram_reporter,ig_android_feed_aut"
    "o_share_to_facebook_dialog,ig_android_arengine_separate_prepare,ig_androi"
    "d_skip_button_content_on_connect_fb_universe,ig_android_igtv_profile_tab,"
    "ig_android_show_fb_name_universe,ig_android_interactions_inline_composer_"
    "extensions_universe,ig_camera_async_space_validation_for_ar,ig_android_pi"
    "geon_sampling,ig_story_camera_reverse_video_experiment,ig_android_live_us"
    "e_timestamp_normalizer,ig_android_profile_lazy_load_carousel_media,ig_and"
    "roid_stories_question_sticker_music_format,ig_business_profile_18h1_holdo"
    "ut_universe,ig_pacing_overriding_universe,ig_android_direct_allow_multili"
    "ne_composition,ig_android_interactions_emoji_extension_followup_universe,"
    "ig_android_story_ads_direct_cta_universe,ig_android_q3lc_transparency_con"
    "trol_settings,ig_stories_selfie_sticker,ig_android_sso_use_trustedapp_uni"
    "verse,ig_android_ad_increase_story_adpreload_priority_universe,ig_android"
    "_interests_netego_dismiss,ig_direct_giphy_gifs_rating,ig_android_shopping"
    "_catalogsearch,ig_android_stories_music_awareness_universe,ig_android_qcc"
    "_perf,ig_android_stories_reels_tray_media_count_check,ig_android_new_fb_p"
    "age_selection,ig_android_facebook_crosspost,ig_android_internal_collab_sa"
    "ve,ig_video_holdout_h2_2017,ig_android_story_sharing_universe,ig_promote_"
    "post_insights_entry_universe,ig_android_direct_thread_store_rewrite,ig_an"
    "droid_qp_clash_management_enabled_v4_universe,ig_branded_content_paid_bra"
    "nded_content,ig_android_large_heap_override,ig_android_live_subscribe_use"
    "r_level_universe,ig_android_igtv_creation_flow,ig_android_video_call_fini"
    "sh_universe,ig_android_direct_mqtt_send,ig_android_do_not_fetch_follow_re"
    "quests_on_success,ig_android_remove_push_notifications,ig_android_vc_dire"
    "ctapp_integration_universe,ig_android_explore_discover_people_entry_point"
    "_universe,ig_android_sonar_prober_universe,ig_android_live_bg_download_fa"
    "ce_filter_assets_universe,ig_android_gif_framerate_throttling,ig_android_"
    "live_webrtc_livewith_params,ig_android_vc_always_start_connection_on_cond"
    "ition_universe,ig_camera_worldtracking_set_scale_by_arclass,ig_android_di"
    "rect_inbox_typing_indicator,ig_android_stories_music_lyrics_scrubber,ig_f"
    "eed_experience,ig_android_direct_new_thread_local_search_fix_universe,ig_"
    "android_appstate_logger,ig_promote_insights_video_views_universe,ig_andro"
    "id_dismiss_recent_searches,ig_android_downloadable_igrtc_module,ig_androi"
    "d_fb_link_ui_polish_universe,ig_stories_music_sticker,ig_android_device_c"
    "apability_framework,ig_scroll_by_two_cards_for_suggested_invite_universe,"
    "ig_android_stories_helium_balloon_badging_universe,ig_android_business_re"
    "move_unowned_fb_pages,ig_android_stories_combined_asset_search,ig_stories"
    "_allow_camera_actions_while_recording,ig_android_analytics_mark_events_as"
    "_offscreen,ig_android_optic_feature_testing,ig_android_camera_universe,ig"
    "_android_optic_photo_cropping_fixes,ig_camera_regiontracking_use_similari"
    "ty_tracker_for_scaling,ig_android_refreshable_list_view_check_spring,feli"
    "x_android_video_quality,ig_android_biz_endpoint_switch,ig_android_direct_"
    "continuous_capture,ig_android_comments_direct_reply_to_author,ig_android_"
    "vc_webrtc_params,ig_android_claim_or_connect_page_on_xpost,ig_android_anr"
    ",ig_android_optic_new_architecture,ig_android_stories_viewer_as_modal_hig"
    "h_end_launch,ig_android_hashtag_follow_chaining_over_logging,ig_new_eof_d"
    "emarcator_universe,ig_android_push_notifications_settings_redesign_univer"
    "se,ig_hashtag_display_universe,ig_fbns_push,coupon_price_test_ad4ad_insta"
    "gram_resurrection_universe,ig_android_live_rendering_looper_universe,ig_a"
    "ndroid_mqtt_cookie_auth_memcache_universe,ig_android_live_end_redirect_un"
    "iverse,ig_android_direct_mutation_manager_media_2,ig_android_ccu_jobsched"
    "uler_outer,ig_smb_ads_holdout_2019_h1_universe,ig_fb_graph_differentiatio"
    "n,ig_android_stories_share_extension_video_segmentation,ig_android_intera"
    "ctions_realtime_typing_indicator_and_live_comments,ig_android_stories_cre"
    "ate_flow_favorites_tooltip,ig_android_live_nerd_stats_universe,ig_android"
    "_universe_video_production,ig_android_hide_reset_with_fb_universe,ig_andr"
    "oid_reactive_feed_like_count,ig_android_stories_music_precapture,ig_andro"
    "id_vc_service_crash_fix_universe,ig_android_shopping_product_overlay,ig_a"
    "ndroid_direct_double_tap_to_like_hearts,ig_camera_android_api_rewrite_uni"
    "verse,ig_android_growth_fci_team_holdout_universe,ig_android_stories_gall"
    "ery_recyclerview_kit_universe,ig_android_story_ads_instant_sub_impression"
    "_universe,ig_business_signup_biz_id_universe,ig_android_save_all,ig_andro"
    "id_main_feed_fragment_scroll_timing_histogram_uni,ig_android_ttcp_improve"
    "ments,ig_android_camera_ar_platform_profile_universe,ig_explore_2018_topi"
    "c_channel_navigation_android_universe,ig_android_live_fault_tolerance_uni"
    "verse,ig_android_stories_viewer_tall_android_cap_media_universe,native_co"
    "ntact_invites_universe,ig_android_dash_script,ig_android_insights_media_h"
    "ashtag_insight_universe,ig_camera_fast_tti_universe,ig_android_stories_wh"
    "atsapp_share,ig_android_inappnotification_rootactivity_tweak,ig_android_r"
    "ender_thread_memory_leak_holdout,ig_android_private_highlights_universe,i"
    "g_android_rate_limit_feed_video_module,ig_android_one_tap_fbshare,ig_shar"
    "e_to_story_toggle_include_shopping_product,ig_android_direct_speed_cam_un"
    "iv,ig_payments_billing_address,ig_android_ufiv3_holdout,ig_android_new_ca"
    "mera_design_container_animations_universe,ig_android_livewith_guest_adapt"
    "ive_camera_universe,ig_android_direct_fix_playing_invalid_visual_message,"
    "ig_shopping_viewer_intent_actions,ig_promote_add_payment_navigation_unive"
    "rse,ig_android_optic_disable_post_capture_preview_restart,ig_android_main"
    "_feed_refresh_style_universe,ig_android_live_analytics,ig_android_story_a"
    "ds_performance_universe_1,ig_android_stories_viewer_modal_activity,ig_and"
    "roid_story_ads_performance_universe_3,ig_android_story_ads_performance_un"
    "iverse_4,ig_android_feed_seen_state_with_view_info,ig_android_ads_profile"
    "_cta_feed_universe,ig_android_vc_cowatch_universe,ig_android_optic_thread"
    "_priorities,ig_android_igtv_chaining,ig_android_live_qa_viewer_v1_univers"
    "e,ig_android_stories_show_story_not_available_error_msg,ig_android_inline"
    "_notifications_recommended_user,ig_shopping_post_insights,ig_android_webr"
    "tc_streamid_salt_universe,ig_android_wellbeing_timeinapp_v1_universe,ig_a"
    "ndroid_profile_cta_v3,ig_android_video_qp_logger_universe,ig_android_cach"
    "e_video_autoplay_checker,ig_android_live_suggested_live_expansion,ig_andr"
    "oid_vc_start_from_direct_inbox_universe,ig_perf_android_holdout,ig_fb_gra"
    "ph_differentiation_only_fb_candidates,ig_android_expired_build_lockout,ig"
    "_promote_lotus_universe,ig_android_video_streaming_upload_universe,ig_and"
    "roid_optic_fast_preview_restart_listener,ig_interactions_h1_2019_team_hol"
    "dout_universe,ig_android_ad_async_ads_universe,ig_camera_android_effect_i"
    "nfo_bottom_sheet_universe,ig_android_stories_feedback_badging_universe,ig"
    "_android_sorting_on_self_following_universe,ig_android_edit_location_page"
    "_info,ig_promote_are_you_sure_universe,ig_android_interactions_feed_label"
    "_below_comments_refactor_universe,ig_android_camera_platform_effect_share"
    "_universe,ig_stories_engagement_swipe_animation_simple_universe,ig_login_"
    "activity,ig_android_direct_quick_replies,ig_android_fbns_optimization_uni"
    "verse,ig_android_stories_alignment_guides_universe,ig_android_rn_ads_mana"
    "ger_universe,ig_explore_2018_post_chaining_account_recs_dedupe_universe,i"
    "g_android_click_to_direct_story_reaction_universe,ig_internal_research_se"
    "ttings,ig_android_stories_video_seeking_audio_bug_fix,ig_android_insights"
    "_holdout,ig_android_swipe_up_area_universe,ig_android_rendering_controls,"
    "ig_android_feed_post_sticker,ig_android_inline_editing_local_prefill,ig_a"
    "ndroid_hybrid_bitmap_v3_prenougat,ig_android_cronet_stack,ig_android_enab"
    "le_igrtc_module,ig_android_scroll_audio_priority,ig_android_shopping_prod"
    "uct_appeals_universe,ig_android_fb_follow_server_linkage_universe,ig_andr"
    "oid_fblocation_universe,ig_android_direct_updated_story_reference_ui,ig_c"
    "amera_holdout_h1_2018_product,live_with_request_to_join_button_universe,i"
    "g_android_music_continuous_capture,ig_android_churned_find_friends_redire"
    "ct_to_discover_people,ig_android_main_feed_new_posts_indicator_universe,i"
    "g_vp9_hd_blacklist,ig_ios_queue_time_qpl_universe,ig_android_split_contac"
    "ts_list,ig_android_connect_owned_page_universe,ig_android_felix_prefetch_"
    "thumbnail_sprite_sheet,ig_android_multi_dex_class_loader_v2,ig_android_wa"
    "tch_and_more_redesign,igtv_feed_previews,ig_android_qp_batch_fetch_cachin"
    "g_enabled_v1_universe,ig_android_profile_edit_phone_universe,ig_android_v"
    "c_renderer_type_universe,ig_android_local_2018_h2_holdout,ig_android_purx"
    "_native_checkout_universe,ig_android_vc_disable_lock_screen_content_acces"
    "s_universe,ig_android_business_transaction_in_stories_creator,android_cam"
    "eracore_ard_ig_integration,ig_video_experimental_encoding_consumption_uni"
    "verse,ig_android_iab_autofill,ig_android_location_page_intent_survey,ig_c"
    "amera_android_segmentation_qe2_universe,ig_android_image_mem_cache_strong"
    "_ref_universe,ig_android_business_promote_refresh_fb_access_token_univers"
    "e,ig_android_stories_samsung_sharing_integration,ig_android_hashtag_heade"
    "r_display,ig_discovery_holdout_2019_h1_universe,ig_android_user_url_deepl"
    "ink_fbpage_endpoint,ig_android_direct_mutation_manager_handler_thread_uni"
    "verse,ig_branded_content_show_settings_universe,ig_android_ad_holdout_wat"
    "chandmore_universe,ig_android_direct_thread_green_dot_presence_universe,i"
    "g_android_camera_new_post_smile_universe,ig_android_shopping_signup_redes"
    "ign_universe,ig_android_vc_missed_call_notification_action_reply,allow_pu"
    "blish_page_universe,ig_android_experimental_onetap_dialogs_universe,ig_pr"
    "omote_ppe_v2_universe,android_cameracore_ig_gl_oom_fixes_universe,ig_andr"
    "oid_multi_capture_camera,ig_android_fb_family_navigation_badging_user,ig_"
    "android_follow_requests_copy_improvements,ig_media_geo_gating,ig_android_"
    "comments_notifications_universe,ig_android_render_output_surface_timeout_"
    "universe,ig_android_drop_frame_check_paused,ig_direct_raven_sharesheet_ra"
    "nking,ig_android_realtime_mqtt_logging,ig_family_bridges_holdout_universe"
    ",ig_android_rainbow_hashtags,ig_android_ad_watchinstall_universe,ig_andro"
    "id_ad_account_top_followers_universe,ig_android_betamap_universe,ig_andro"
    "id_video_ssim_report_universe,ig_android_cache_network_util,ig_android_le"
    "ak_detector_upload_universe,ig_android_carousel_prefetch_bumping,ig_fbns_"
    "preload_default,ig_android_inline_appeal_show_new_content,ig_fbns_kill_sw"
    "itch,ig_hashtag_following_holdout_universe,ig_android_show_weekly_ci_upse"
    "ll_limit,ig_android_direct_reel_options_entry_point_2_universe,enable_cre"
    "ator_account_conversion_v0_animation,ig_android_http_service_same_thread,"
    "ig_camera_holdout_h1_2018_performance,ig_android_direct_mutation_manager_"
    "cancel_fix_universe,ig_music_dash,ig_android_fb_url_universe,ig_android_r"
    "eel_raven_video_segmented_upload_universe,ig_android_promote_native_migra"
    "tion_universe,ig_camera_android_badge_face_effects_universe,ig_android_hy"
    "brid_bitmap_v3_nougat,ig_android_multi_author_story_reshare_universe,ig_a"
    "ndroid_vc_camera_zoom_universe,ig_android_enable_request_compression_ccu,"
    "ig_android_video_controls_universe,ig_android_logging_metric_universe_v2,"
    "ig_android_xposting_newly_fbc_people,ig_android_visualcomposer_inapp_noti"
    "fication_universe,ig_android_contact_point_upload_rate_limit_killswitch,i"
    "g_android_webrtc_encoder_factory_universe,ig_android_search_impression_lo"
    "gging,ig_android_handle_username_in_media_urls_universe,ig_android_sso_ko"
    "totoro_app_universe,ig_android_mi_holdout_h1_2019,ig_android_igtv_autopla"
    "y_on_prepare,ig_file_based_session_handler_2_universe,ig_branded_content_"
    "tagging_upsell,ig_shopping_insights_parity_universe_android,ig_android_li"
    "ve_ama_universe,ig_android_external_gallery_import_affordance,ig_android_"
    "updatelistview_on_loadmore,ig_android_optic_new_zoom_controller,ig_androi"
    "d_hide_type_mode_camera_button,ig_android_photos_qpl,ig_android_reel_impr"
    "esssion_cache_key_qe_universe,ig_android_show_profile_picture_upsell_in_r"
    "eel_universe,ig_android_live_viewer_tap_to_hide_chrome_universe,ig_discov"
    "ery_holdout_universe,ig_android_direct_import_google_photos2,ig_android_s"
    "tories_tray_in_viewer,ig_android_request_verification_badge,ig_android_di"
    "rect_unlimited_raven_replays_inthreadsession_fix,ig_android_netgo_cta,ig_"
    "android_viewpoint_netego_universe,ig_android_stories_separate_overlay_cre"
    "ation,ig_android_iris_improvements,ig_android_biz_conversion_naming_test,"
    "ig_android_fci_empty_feed_friend_search,ig_android_hashtag_page_support_p"
    "laces_tab,ig_camera_android_ar_platform_universe,ig_android_stories_viewe"
    "r_prefetch_improvements,ig_android_optic_camera_warmup,ig_android_place_s"
    "earch_profile_image,ig_android_interactions_in_feed_comment_view_universe"
    ",ig_android_fb_sharing_shortcut,ig_android_oreo_hardware_bitmap,ig_androi"
    "d_analytics_diagnostics_universe,ig_android_insights_creative_tutorials_u"
    "niverse,ig_android_vc_universe,ig_android_profile_unified_follow_view,ig_"
    "android_collect_os_usage_events_universe,ig_android_shopping_nux_timing_u"
    "niverse,ig_android_fbpage_on_profile_side_tray,ig_android_native_logcat_i"
    "nterceptor,ig_android_direct_thread_content_picker,ig_android_notif_impro"
    "vement_universe,ig_face_effect_ranking,ig_android_shopping_more_from_busi"
    "ness,ig_feed_content_universe,ig_android_hacked_account_reporting,ig_andr"
    "oid_disk_usage_logging_universe,ig_android_ad_redesign_iab_universe,ig_an"
    "droid_banyan_migration,ig_android_profile_event_leak_holdout,ig_android_s"
    "tories_loading_automatic_retry,ig_android_gqls_typing_indicator,ag_family"
    "_bridges_2018_h2_holdout,ig_promote_net_promoter_score_universe,ig_androi"
    "d_direct_last_seen_message_indicator,ig_android_biz_conversion_suggest_bi"
    "z_nux,ig_android_log_mediacodec_info,ig_android_vc_participant_state_call"
    "ee_universe,ig_camera_android_boomerang_attribution_universe,ig_android_s"
    "tories_weblink_creation,ig_android_horizontal_swipe_lfd_logging,ig_profil"
    "e_company_holdout_h2_2018,ig_android_ads_manager_pause_resume_ads_univers"
    "e,ig_promote_fix_expired_fb_accesstoken_android_universe,ig_android_stori"
    "es_media_seen_batching_universe,ig_android_interactions_nav_to_permalink_"
    "followup_universe,ig_android_live_titles_viewer_side_view_title_universe,"
    "ig_android_direct_mark_as_read_notif_action,ig_android_edit_highlight_red"
    "esign,ig_android_direct_mutation_manager_backoff_universe,ig_android_inte"
    "ractions_comment_like_for_all_feed_universe,ig_android_mi_skip_analytic_e"
    "vent_pool_universe,ig_android_fbc_upsell_on_dp_first_load,ig_android_audi"
    "o_ingestion_params,ig_android_video_call_participant_state_caller_univers"
    "e,ig_fbns_shared,ig_feed_engagement_holdout_2018_h1,ig_camera_android_bg_"
    "processor,ig_android_optic_new_features_implementation,ig_android_stories"
    "_reel_interactive_tap_target_size,ig_android_video_live_trace_universe,ig"
    "_android_igtv_browse_with_pip_v2,ig_android_interactive_listview_during_r"
    "efresh,ig_android_igtv_feed_banner_universe,ig_android_unfollow_from_main"
    "_feed_v2,ig_android_self_story_setting_option_in_menu,ig_android_ad_watch"
    "lead_universe,ufi_share,ig_android_live_special_codec_size_list,ig_androi"
    "d_live_qa_broadcaster_v1_universe,ig_android_hide_stories_viewer_list_uni"
    "verse,ig_android_direct_albums,ig_android_business_transaction_in_stories"
    "_consumer,ig_android_scroll_stories_tray_to_front_when_stories_ready,ig_a"
    "ndroid_direct_thread_composer,instagram_android_stories_sticker_tray_rede"
    "sign,ig_camera_android_superzoom_icon_position_universe,ig_android_busine"
    "ss_cross_post_with_biz_id_infra,ig_android_photo_invites,ig_android_reel_"
    "tray_item_impression_logging_viewpoint,ig_account_identity_2018_h2_lockdo"
    "wn_phone_global_holdout,ig_android_high_res_gif_stickers,ig_close_friends"
    "_v4,ig_fb_cross_posting_sender_side_holdout,ig_android_ads_history_univer"
    "se,ig_android_comments_composer_newline_universe,ig_rtc_use_dtls_srtp,ig_"
    "promote_media_picker_universe,ig_android_live_start_live_button_universe,"
    "ig_android_vc_ongoing_call_notification_universe,ig_android_rate_limit_fe"
    "ed_item_viewable_helper,ig_android_bitmap_attribution_check,ig_android_ig"
    "_to_fb_sync_universe,ig_android_reel_viewer_data_buffer_size,ig_two_fac_t"
    "otp_enable,ig_android_vc_missed_call_notification_action_call_back,ig_and"
    "roid_stories_landscape_mode,ig_android_ad_view_ads_native_universe,ig_and"
    "roid_igtv_whitelisted_for_web,ig_android_global_prefetch_scheduler,ig_and"
    "roid_live_thread_delay_for_mute_universe,ig_close_friends_v4_global,ig_an"
    "droid_share_publish_page_universe,ig_android_new_camera_design_universe,i"
    "g_direct_max_participants,ig_promote_hide_local_awareness_universe,ig_and"
    "roid_graphql_survey_new_proxy_universe,ig_android_fs_creation_flow_tweaks"
    ",ig_android_ad_watchbrowse_cta_universe,ig_android_camera_new_tray_behavi"
    "or_universe,ig_android_direct_expiring_media_loading_errors,ig_android_sh"
    "ow_fbunlink_button_based_on_server_data,ig_android_downloadable_vp8_modul"
    "e,ig_android_igtv_feed_trailer,ig_android_fb_profile_integration_universe"
    ",ig_android_profile_private_banner,ig_camera_android_focus_attribution_un"
    "iverse,ig_android_rage_shake_whitelist,ig_android_su_follow_back,ig_andro"
    "id_prefetch_notification_data,ig_android_webrtc_icerestart_on_failure_uni"
    "verse,ig_android_vpvd_impressions_universe,ig_android_payload_based_sched"
    "uling,ig_android_grid_cell_count,ig_android_new_highlight_button_text,ig_"
    "android_direct_search_bar_redesign,ig_android_hashtag_row_preparer,ig_and"
    "roid_ad_pbia_header_click_universe,ig_android_direct_visual_viewer_ppr_fi"
    "x,ig_background_prefetch,ig_camera_android_focus_in_post_universe,ig_andr"
    "oid_time_spent_dashboard,ig_android_direct_vm_activity_sheet,ig_promote_p"
    "olitical_ads_universe,ig_android_stories_auto_retry_reels_media_and_segme"
    "nts,ig_android_recommend_accounts_killswitch,ig_shopping_video_half_sheet"
    ",ig_android_ad_iab_qpl_kill_switch_universe,ig_android_interactions_direc"
    "t_share_comment_universe,ig_android_vc_sounds_universe,ig_camera_android_"
    "cache_format_picker_children,ig_android_post_live_expanded_comments_view_"
    "universe,ig_android_always_use_server_recents,ig_android_qp_slot_cooldown"
    "_enabled_universe,ig_android_asset_picker_improvements,ig_android_direct_"
    "activator_cards,ig_android_pending_media_manager_init_fix_universe,ig_and"
    "roid_facebook_global_state_sync_frequency_universe,ig_android_network_tra"
    "ce_migration,ig_android_creation_new_post_title,ig_android_reverse_audio,"
    "ig_android_camera_gallery_upload_we_universe,ig_android_direct_inbox_asyn"
    "c_diffing_universe,ig_android_live_save_to_camera_roll_limit_by_screen_si"
    "ze_universe,ig_android_profile_phone_autoconfirm_universe,ig_direct_stori"
    "es_questions,ig_android_optic_surface_texture_cleanup,ig_android_vc_use_t"
    "imestamp_normalizer,ig_android_post_recs_show_more_button_universe,ig_sho"
    "pping_checkout_mvp_experiment,ig_android_direct_pending_media,ig_android_"
    "scroll_main_feed,ig_android_intialization_chunk_410,ig_android_story_ads_"
    "default_long_video_duration,ig_android_interactions_mention_search_presen"
    "ce_dot_universe,ig_android_stories_music_sticker_position,ig_android_dire"
    "ct_character_limit,ig_stories_music_themes,ig_android_nametag_save_experi"
    "ment_universe,ig_android_media_rows_prepare_10_31,ig_android_fs_new_galle"
    "ry,ig_android_stories_hide_retry_button_during_loading_launch,ig_android_"
    "remove_follow_all_fb_list,ig_android_biz_conversion_editable_profile_revi"
    "ew_universe,ig_android_shopping_checkout_mvp,ig_android_local_info_page,i"
    "g_android_direct_log_badge_count"
)

LOGIN_EXPERIMENTS = (
    "ig_android_fci_onboarding_friend_search,ig_android_device_detection_info_"
    "upload,ig_android_autosubmit_password_recovery_universe,ig_growth_android"
    "_profile_pic_prefill_with_fb_pic_2,ig_account_identity_logged_out_signals"
    "_global_holdout_universe,ig_android_background_voice_phone_confirmation_p"
    "refilled_phone_number_only,ig_android_login_identifier_fuzzy_match,ig_and"
    "roid_one_tap_aymh_redesign_universe,ig_android_keyboard_detector_fix,ig_a"
    "ndroid_suma_landing_page,ig_android_direct_main_tab_universe,ig_android_a"
    "ymh_signal_collecting_kill_switch,ig_android_login_forgot_password_univer"
    "se,ig_android_smartlock_hints_universe,ig_android_smart_prefill_killswitc"
    "h,ig_android_account_switch_infra_universe,ig_android_multi_tap_login_new"
    ",ig_android_email_one_tap_auto_login_during_reg,ig_android_category_searc"
    "h_in_sign_up,ig_android_report_nux_completed_device,ig_android_reg_login_"
    "profile_photo_universe,ig_android_caption_typeahead_fix_on_o_universe,ig_"
    "android_nux_add_email_device,ig_android_ci_opt_in_placement,ig_android_re"
    "member_password_at_login,ig_type_ahead_recover_account,ig_android_analyti"
    "cs_accessibility_event,ig_sem_resurrection_logging,ig_android_abandoned_r"
    "eg_flow,ig_android_editable_username_in_reg,ig_android_account_recovery_a"
    "uto_login,ig_android_sim_info_upload,ig_android_skip_signup_from_one_tap_"
    "if_no_fb_sso,ig_android_hide_fb_flow_in_add_account_flow,ig_android_mobil"
    "e_http_flow_device_universe,ig_account_recovery_via_whatsapp_universe,ig_"
    "android_hide_fb_button_when_not_installed_universe,ig_prioritize_user_inp"
    "ut_on_switch_to_signup,ig_android_gmail_oauth_in_reg,ig_android_login_saf"
    "etynet,ig_android_gmail_autocomplete_account_over_one_tap,ig_android_back"
    "ground_voice_phone_confirmation,ig_android_phone_auto_login_during_reg,ig"
    "_android_hide_typeahead_for_logged_users,ig_android_hindi,ig_android_reg_"
    "modularization_universe,ig_android_bottom_sheet,ig_android_snack_bar_hidi"
    "ng,ig_android_one_tap_fallback_auto_login,ig_android_device_verification_"
    "separate_endpoint,ig_account_recovery_with_code_android_universe,ig_andro"
    "id_onboarding_skip_fb_connect,ig_android_phone_reg_redesign_universe,ig_a"
    "ndroid_universe_noticiation_channels,ig_android_media_cache_cleared_unive"
    "rse,ig_android_account_linking_universe,ig_android_hsite_prefill_new_carr"
    "ier,ig_android_retry_create_account_universe,ig_android_family_apps_user_"
    "values_provider_universe,ig_android_reg_nux_headers_cleanup_universe,ig_a"
    "ndroid_dialog_email_reg_error_universe,ig_android_ci_fb_reg,ig_android_de"
    "vice_info_foreground_reporting,ig_fb_invite_entry_points,ig_android_devic"
    "e_verification_fb_signup,ig_android_suma_biz_account,ig_android_onetaplog"
    "in_optimization,ig_video_debug_overlay,ig_android_ask_for_permissions_on_"
    "reg,ig_android_display_full_country_name_in_reg_universe,ig_android_exopl"
    "ayer_settings,ig_android_persistent_duplicate_notif_checker,ig_android_se"
    "curity_intent_switchoff,ig_android_background_voice_confirmation_block_ar"
    "gentinian_numbers,ig_android_do_not_show_back_button_in_nux_user_list,ig_"
    "android_passwordless_auth,ig_android_direct_main_tab_account_switch,ig_an"
    "droid_modularized_dynamic_nux_universe,ig_android_icon_perf2,ig_android_e"
    "mail_suggestions_universe,ig_android_fb_account_linking_sampling_freq_uni"
    "verse,ig_android_prefill_full_name_from_fb,ig_android_access_flow_prefill"
)

LAUNCHER_CONFIGS = (
    "ig_android_felix_release_players,ig_user_mismatch_soft_error,"
    "ig_android_os_version_blocking_config,"
    "ig_android_carrier_signals_killswitch,fizz_ig_android,"
    "ig_mi_block_expired_events,ig_android_killswitch_perm_direct_ssim,"
    "ig_fbns_blocked"
)

SUPPORTED_CAPABILITIES = [
    {
        "name": "SUPPORTED_SDK_VERSIONS",
        "value": "13.0,14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24."
        + "0,25.0,26.0,27.0,28.0,29.0,30.0,31.0,32.0,33.0,34.0,35.0,36.0,37.0,"
        + "38.0,39.0,40.0,41.0,42.0,43.0,44.0,45.0,46.0,47.0,48.0,49.0,50.0,51"
        + ".0,52.0,53.0",
    },
    {"name": "FACE_TRACKER_VERSION", "value": "12"},
    {"name": "segmentation", "value": "segmentation_enabled"},
    {"name": "WORLD_TRACKER", "value": "WORLD_TRACKER_ENABLED"},
]
